@@ -1,11 +1,15 @@
 // Copyright (c) The nextest Contributors
 // SPDX-License-Identifier: MIT OR Apache-2.0
 
+use crate::CommandError;
 use camino::{Utf8Path, Utf8PathBuf};
 use serde::{Deserialize, Serialize};
-use std::{collections::BTreeMap, fmt, path::PathBuf, process::Command};
-
-use crate::CommandError;
+use std::{
+    collections::{BTreeMap, BTreeSet},
+    fmt,
+    path::PathBuf,
+    process::Command,
+};
 
 /// Command builder for `cargo nextest list`.
 #[derive(Clone, Debug, Default)]
@@ -114,10 +118,13 @@ impl ListCommand {
 }
 
 /// Root element for a serializable list of tests generated by nextest.
-#[derive(Clone, Debug, Default, Eq, PartialEq, Deserialize, Serialize)]
+#[derive(Clone, Debug, Eq, PartialEq, Deserialize, Serialize)]
 #[serde(rename_all = "kebab-case")]
 #[non_exhaustive]
 pub struct TestListSummary {
+    /// Rust metadata used for builds and test runs.
+    pub rust_build_meta: RustBuildMetaSummary,
+
     /// Number of tests (including skipped and ignored) across all binaries.
     pub test_count: usize,
 
@@ -127,6 +134,14 @@ pub struct TestListSummary {
 }
 
 impl TestListSummary {
+    /// Creates a new `TestListSummary` with the given Rust metadata.
+    pub fn new(rust_build_meta: RustBuildMetaSummary) -> Self {
+        Self {
+            rust_build_meta,
+            test_count: 0,
+            rust_suites: BTreeMap::new(),
+        }
+    }
     /// Parse JSON output from `cargo nextest list --format json`.
     pub fn parse_json(json: impl AsRef<str>) -> Result<Self, serde_json::Error> {
         serde_json::from_str(json.as_ref())
@@ -182,10 +197,27 @@ pub struct RustTestBinarySummary {
 #[derive(Clone, Debug, PartialEq, Eq, Deserialize, Serialize)]
 #[serde(rename_all = "kebab-case")]
 pub struct BinaryListSummary {
+    /// Rust metadata used for builds and test runs.
+    pub rust_build_meta: RustBuildMetaSummary,
+
     /// The list of Rust test binaries (indexed by binary-id).
     pub rust_binaries: BTreeMap<String, RustTestBinarySummary>,
 }
 
+/// Rust metadata used for builds and test runs.
+#[derive(Clone, Debug, PartialEq, Eq, Deserialize, Serialize)]
+#[serde(rename_all = "kebab-case")]
+pub struct RustBuildMetaSummary {
+    /// The target directory for Rust artifacts.
+    pub target_directory: Utf8PathBuf,
+
+    /// Base output directories, relative to the target directory.
+    pub base_output_directories: BTreeSet<Utf8PathBuf>,
+
+    /// Linked paths, relative to the target directory.
+    pub linked_paths: BTreeSet<Utf8PathBuf>,
+}
+
 /// A serializable suite of tests within a Rust test binary.
 ///
 /// Part of a [`TestListSummary`].
